# QTMimport
This small module opens data files generated by the QTMtoolbox (.csv format) and parses the data into a single object (class).
Each variable that was measured is an attribute of this class, and contains the header name, data, etc. 